==> cli-3.6.2-sources.jar: com/xebialabs/deployit/cli/api/Proxies.java <==
package com.xebialabs.deployit.cli.api;

import java.util.Map;
import java.util.HashMap;
import org.jboss.resteasy.client.ProxyFactory;
import org.jboss.resteasy.client.core.executors.ApacheHttpClientExecutor;
import com.xebialabs.deployit.cli.Cli;
import com.xebialabs.deployit.cli.CliOptions;
import com.xebialabs.deployit.core.api.*;
import com.xebialabs.deployit.core.api.resteasy.ResteasyHelper;

/**
 */
public class Proxies {
	private final Map<Class<?>, Object> registeredProxies = new HashMap<Class<?>, Object>();
	private final Cli.Authentication authentication;
	private final String host;

	public Proxies(final CliOptions options, final Cli.Authentication authentication) {
		this.authentication = authentication;
		host = options.getUrl();
		ResteasyHelper.buildDefaultResteasyProviderFactory().build();
		registerProxies();
	}

	private void registerProxies() {
		registerProxy(DeploymentProxy.class);
		registerProxy(ImportablePackageProxy.class);
		registerProxy(RepositoryProxy.class);
		registerProxy(QueryProxy.class);
		registerProxy(UserProxy.class);
		registerProxy(DiscoveryProxy.class);
		registerProxy(HistoryProxy.class);
        registerProxy(DescriptorProxy.class);
        registerProxy(TaskProxy.class);
        registerProxy(ExportProxy.class);
        registerProxy(ReportProxy.class);
		registerProxy(SecurityProxy.class);
		registerProxy(ServerProxy.class);
		registerProxy(ControlTaskProxy.class);
	}

	public String getHost() {
		return host;
	}

	private void registerProxy(final Class<?> proxyClass) {
		final ApacheHttpClientExecutor clientExecutor = new ApacheHttpClientExecutor(authentication.getHttpClient());

		registeredProxies.put(proxyClass, ProxyFactory.create(proxyClass, host, clientExecutor));
	}

	@SuppressWarnings("unchecked")
	private <T> T getRestEasyProxyInstance(Class<T> proxyClass) {
		return (T) registeredProxies.get(proxyClass);
	}

	public final Cli.Authentication getAuthentication(){
		return this.authentication;
	}

	public ControlTaskProxy getControlTask() {
		return getRestEasyProxyInstance(ControlTaskProxy.class);
	}

	public DeploymentProxy getDeployment() {
		return getRestEasyProxyInstance(DeploymentProxy.class);
	}

	public ImportablePackageProxy getImportablePackage() {
		return getRestEasyProxyInstance(ImportablePackageProxy.class);
	}

	public RepositoryProxy getRepository() {
		return getRestEasyProxyInstance(RepositoryProxy.class);
	}

	public QueryProxy getQuery() {
		return getRestEasyProxyInstance(QueryProxy.class);
	}
	
	public HistoryProxy getHistory() {
		return getRestEasyProxyInstance(HistoryProxy.class);
	}

	public DiscoveryProxy getDiscovery() {
		return getRestEasyProxyInstance(DiscoveryProxy.class);
	}

	public TaskProxy getTaskRegistry() {
		return getRestEasyProxyInstance(TaskProxy.class);
	}
	
	public ExportProxy getTaskExport() {
		return getRestEasyProxyInstance(ExportProxy.class);
	}

	public UserProxy getUser() {
		return getRestEasyProxyInstance(UserProxy.class);
	}

    public DescriptorProxy getDescriptors() {
        return getRestEasyProxyInstance(DescriptorProxy.class);
    }
    
    public ReportProxy getReport() {
    	return getRestEasyProxyInstance(ReportProxy.class);
    }

	public SecurityProxy getSecurity() {
		return getRestEasyProxyInstance(SecurityProxy.class);
	}

	public ServerProxy getServer() {
		return getRestEasyProxyInstance(ServerProxy.class);
	}
}

==> cli-3.7.3-sources.jar: com/xebialabs/deployit/cli/api/Proxies.java <==
package com.xebialabs.deployit.cli.api;

import java.util.HashMap;
import java.util.Map;

import org.jboss.resteasy.client.ProxyFactory;
import org.jboss.resteasy.client.core.executors.ApacheHttpClientExecutor;

import com.xebialabs.deployit.cli.Cli;
import com.xebialabs.deployit.cli.CliOptions;
import com.xebialabs.deployit.core.api.ControlTaskProxy;
import com.xebialabs.deployit.core.api.DeploymentProxy;
import com.xebialabs.deployit.core.api.ReferenceDataProxy;
import com.xebialabs.deployit.core.api.DiscoveryProxy;
import com.xebialabs.deployit.core.api.ExportProxy;
import com.xebialabs.deployit.core.api.ImportablePackageProxy;
import com.xebialabs.deployit.core.api.QueryProxy;
import com.xebialabs.deployit.core.api.ReportProxy;
import com.xebialabs.deployit.core.api.RepositoryProxy;
import com.xebialabs.deployit.core.api.SecurityProxy;
import com.xebialabs.deployit.core.api.ServerProxy;
import com.xebialabs.deployit.core.api.TaskProxy;
import com.xebialabs.deployit.core.api.UserProxy;
import com.xebialabs.deployit.core.api.resteasy.ResteasyHelper;
import org.jboss.resteasy.plugins.server.servlet.ResteasyBootstrap;
import org.jboss.resteasy.spi.ResteasyDeployment;

/**
 */
public class Proxies {
	private final Map<Class<?>, Object> registeredProxies = new HashMap<Class<?>, Object>();
	private final Cli.Authentication authentication;
	private final String host;

	public Proxies(final CliOptions options, final Cli.Authentication authentication) {
		this.authentication = authentication;
		host = options.getUrl();
		ResteasyDeployment resteasyDeployment = new ResteasyDeployment();
		resteasyDeployment.start();
		registerProxies();
	}

	private void registerProxies() {
		registerProxy(DeploymentProxy.class);
		registerProxy(ImportablePackageProxy.class);
		registerProxy(RepositoryProxy.class);
		registerProxy(QueryProxy.class);
		registerProxy(UserProxy.class);
		registerProxy(DiscoveryProxy.class);
        registerProxy(ReferenceDataProxy.class);
        registerProxy(TaskProxy.class);
        registerProxy(ExportProxy.class);
        registerProxy(ReportProxy.class);
		registerProxy(SecurityProxy.class);
		registerProxy(ServerProxy.class);
		registerProxy(ControlTaskProxy.class);
	}

	public String getHost() {
		return host;
	}

	private void registerProxy(final Class<?> proxyClass) {
		final ApacheHttpClientExecutor clientExecutor = new ApacheHttpClientExecutor(authentication.getHttpClient());

		registeredProxies.put(proxyClass, ProxyFactory.create(proxyClass, host, clientExecutor));
	}

	@SuppressWarnings("unchecked")
	private <T> T getRestEasyProxyInstance(Class<T> proxyClass) {
		return (T) registeredProxies.get(proxyClass);
	}

	public final Cli.Authentication getAuthentication(){
		return this.authentication;
	}

	public ControlTaskProxy getControlTask() {
		return getRestEasyProxyInstance(ControlTaskProxy.class);
	}

	public DeploymentProxy getDeployment() {
		return getRestEasyProxyInstance(DeploymentProxy.class);
	}

	public ImportablePackageProxy getImportablePackage() {
		return getRestEasyProxyInstance(ImportablePackageProxy.class);
	}

	public RepositoryProxy getRepository() {
		return getRestEasyProxyInstance(RepositoryProxy.class);
	}

	public QueryProxy getQuery() {
		return getRestEasyProxyInstance(QueryProxy.class);
	}
	
	public DiscoveryProxy getDiscovery() {
		return getRestEasyProxyInstance(DiscoveryProxy.class);
	}

	public TaskProxy getTaskRegistry() {
		return getRestEasyProxyInstance(TaskProxy.class);
	}
	
	public ExportProxy getTaskExport() {
		return getRestEasyProxyInstance(ExportProxy.class);
	}

	public UserProxy getUser() {
		return getRestEasyProxyInstance(UserProxy.class);
	}

    public ReferenceDataProxy getReferenceData() {
        return getRestEasyProxyInstance(ReferenceDataProxy.class);
    }
    
    public ReportProxy getReport() {
    	return getRestEasyProxyInstance(ReportProxy.class);
    }

	public SecurityProxy getSecurity() {
		return getRestEasyProxyInstance(SecurityProxy.class);
	}

	public ServerProxy getServer() {
		return getRestEasyProxyInstance(ServerProxy.class);
	}
}
